.. -*- mode: rst ; ispell-local-dictionary: "american" -*-

.. include:: _manpage-header.rst

==========================
git flow status
==========================
-------------------------------------------------------------
Show branch status
-------------------------------------------------------------


Synopsis
-----------

`git flow status`


Description
-----------

Show some status about the current branches.


Examples
-----------

::

  $ git flow status
    develop: 386bc4b
    feature/branch-manager-hooks: cf3e57f
  * feature/update-docs: c109555
    master: f8ea3eb

.. include:: _manpage-footer.rst
